# Class: puppet_ent_agent
#
# This class manages the Puppet Enterprise (PE) agent.
#
# Parameters:
#
# Actions:
#   - Configure PE agent
#   - Upgrade PE agent if required
#   - Manage pe-puppet service
#
# Requires:
#
# Sample Usage:
#
class puppet_ent_agent (
  $config            = $puppet_ent_agent::params::config,
  $package_ensure    = $puppet_ent_agent::params::package_ensure,
  $master            = $puppet_ent_agent::params::master,
  $agent_server      = $puppet_ent_agent::params::agent_servername,
  $agent_caserver    = $puppet_ent_agent::params::agent_caservername,
  $agent_environment = $puppet_ent_agent::params::agent_environment,
  $staging_dir       = $puppet_ent_agent::params::staging_dir,
  $windows_source    = $puppet_ent_agent::params::windows_source,
  $version           = $puppet_ent_agent::params::version,
) inherits puppet_ent_agent::params {

  validate_absolute_path($config)
  validate_string($package_ensure)
  validate_string($master)
  validate_string($agent_server)
  validate_string($agent_caserver)
  validate_string($agent_environment)
  validate_string($staging_dir)
  validate_string($windows_source)
  validate_string($version)

  class { '::puppet_ent_agent::install': } ->
  class { '::puppet_ent_agent::config': } ->
  class { '::puppet_ent_agent::service': }

}
